library(ggplot2)
library(grid)
library(gridExtra)
library(reshape2)
library(data.table)
library(gdata)
library(svglite)
library(dplyr)
library(quantreg)

clean<-theme_bw() + theme(plot.title = element_text(face="bold",
                                                    size=12), axis.title.x =
                            element_text(face="bold", size=12), axis.text.x =
                            element_text(size=10), axis.text.y =
                            element_text(size=10), axis.title.y =
                            element_text(face="bold", size=12, angle=90), legend.position="none")

dtf <- read.csv(file="results_lateness.csv", sep=";", dec=",", header=T)
dtf <- dtf[dtf$ALGORITHM!="EDF", c(2,3,4,5,6)]
dt <- data.table(dtf)
dt$LOAD_RATE <- as.numeric(as.character(dt$LOAD_RATE))
dt$HIT_VALUE_RATIO <- as.numeric(as.character(dt$HIT_VALUE_RATIO))

dt_dvd1 <- subset(dtf, ALGORITHM == "DVD1")
dt_dtd1 <- subset(dtf, ALGORITHM == "DTD1")
dt_diff <- dt_dtd1[order(dt_dtd1$SCENARIO_INDEX),c("SCENARIO_INDEX", "MEAN_LATENESS_LIMIT")]
dt_diff$HVR_DIFF <- dt_dtd1[order(dt_dtd1$SCENARIO_INDEX),c("HIT_VALUE_RATIO")] - dt_dvd1[order(dt_dvd1$SCENARIO_INDEX),c("HIT_VALUE_RATIO")]

g <- ggplot(dt_diff, aes(x=MEAN_LATENESS_LIMIT, y=HVR_DIFF)) + geom_smooth() + scale_x_continuous(trans='log2') + scale_y_continuous(labels = scales::percent) + ylab("DTD1 HVR - DVD1 HVR") + xlab("Mean lateness limit") + theme(legend.title = element_blank()) + clean
plot(g)
ggsave(g, width=5, height=2.5, dpi=600, file='hvr_vs_lateness_diff.pdf')
