library(ggplot2)
library(grid)
library(gridExtra)
library(reshape2)
library(data.table)
library(gdata)
library(svglite)
library(dplyr)

clean<-theme_bw() + theme(plot.title = element_text(face="bold",
                                                   size=12), axis.title.x =
                           element_text(face="bold", size=12), axis.text.x =
                           element_text(size=10), axis.text.y =
                           element_text(size=10), axis.title.y =
                           element_text(face="bold", size=12, angle=90), legend.position="none")

dtf <- read.csv(file="results_performance.csv", sep=";", dec=",", header=T)
dt <- data.table(dtf)

# Boxplot of algorithms hit value ratio for each load rate
dt$LOAD_RATE <- as_numeric(dt$LOAD_RATE)
dt[, ALGORITHM:=droplevels(ALGORITHM)]
dt$ALGORITHM <- factor(dt$ALGORITHM,levels=c("SVD","SDVD","DVD2","DVD1","DTD2","DTD1","OPTI_LOWER","OPTI_UPPER"))
dt <- dt[order(dt$ALGORITHM)]
dt$MEAN_HIT_VALUE_RATIO <- tapply(dt$HIT_VALUE_RATIO, dt$ALGORITHM, mean)
pc_units <- function(x) paste0(as.numeric(x)*100, '%')
pc_labeller <- function(x, prefix) paste0('Load rate ', pc_units(x))
g1 <- ggplot(dt, aes(x=ALGORITHM, y=HIT_VALUE_RATIO, group=ALGORITHM, fill=ALGORITHM))+clean + geom_boxplot() + stat_summary(fun.y=mean, geom="point", shape=4, size=3) + coord_flip() + scale_y_continuous(labels = scales::percent) + facet_wrap(. ~ LOAD_RATE, ncol=1, labeller=as_labeller(pc_labeller)) + ylab("HIT VALUE RATIO") + xlab("ALGORITHM") + clean
show(g1)
ggsave(g1, width=7, height=7, dpi=600, file='hit_value_ratio_by_load_rate.pdf')

# Mean HVR of algorithms for each load rate
dt2 <- dt %>% filter(ALGORITHM %in% c("SDVD", "SVD", "DVD1", "DTD1"))
dt2$LOAD_RATE <- factor(dt2$LOAD_RATE, levels=c("0.25", "1.0", "4.0", "16.0"))
dt2$ALGORITHM <- factor(dt2$ALGORITHM,levels=c("SDVD","SVD", "DVD1", "DTD1"))
g2 <- ggplot(dt2, aes(x=ALGORITHM, y=HIT_VALUE_RATIO, group=LOAD_RATE)) + stat_summary(fun.y=mean, geom="line") + scale_y_continuous(labels = scales::percent) + facet_wrap(. ~ LOAD_RATE, ncol=2, labeller=as_labeller(pc_labeller), scales='free') + theme(axis.title.x=element_blank()) + ylab('Mean HVR')
show(g2)
ggsave(g2, width=5, height=4, dpi=600, file='mean_hit_value_ratio_by_load_rate.pdf')